from setuptools import setup,find_packages


setup(
    name='MuhekoNikolasVersionsDumpTest',
    author= "Muheko Nikolas",
    version= "0.0.1",
    packages=find_packages(),
    install_requires=[""]
)

